@@ -1,7 +1,7 @@
 from igloo.models.user import User
 from igloo.models.access_token import AccessToken
 from igloo.models.pending_share import PendingShare
-from igloo.models.environment import Environment
+from igloo.models.collection import Collection
 from igloo.models.thing import Thing
 from igloo.models.float_variable import FloatVariable
 from igloo.models.variable import Variable
@@ -25,8 +25,8 @@ class QueryRoot:
     def user(self, id=None, email=None):
         return User(self.client, id=id, email=email)
 
-    def environment(self, id):
-        return Environment(self.client, id)
+    def collection(self, id):
+        return Collection(self.client, id)
 
     def thing(self, id):
         return Thing(self.client, id)
@@ -43,14 +43,14 @@ class QueryRoot:
     def boolean_variable(self, id):
         return BooleanVariable(self.client, id)
 
-    def file_variable(self, id):
-        return FileVariable(self.client, id)
+    # def file_variable(self, id):
+    #     return FileVariable(self.client, id)
 
     def float_series_variable(self, id):
         return FloatSeriesVariable(self.client, id)
 
-    def category_series_variable(self, id):
-        return CategorySeriesVariable(self.client, id)
+    # def category_series_variable(self, id):
+    #     return CategorySeriesVariable(self.client, id)
 
     def pending_share(self, id):
         return PendingShare(self.client, id)
@@ -67,11 +67,11 @@ class QueryRoot:
     def float_series_node(self, id):
         return FloatSeriesNode(self.client, id)
 
-    def category_series_node(self, id):
-        return CategorySeriesNode(self.client, id)
+    # def category_series_node(self, id):
+    #     return CategorySeriesNode(self.client, id)
 
     def get_new_totp_secret(self):
-        return self.client.query("{getNewTotpSecret{secret,qrCode}}", keys=["getNewTotpSecret"])
+        return self.client.query("{totpSecret{secret,qrCode}}", keys=["totpSecret"])
 
     def verify_password(self, password, email=undefined):
         email_arg = parse_arg("email", email)
